pub struct AllShortestPaths {
pub vertices: Vec<Vec<VertexId>>,
pub edges: Vec<Vec<EdgeId>>,
pub nrgeo: Vec<i64>,
}Expand description
All the shortest paths from one source, as returned by
Graph::get_all_shortest_paths.
Fields
vertices: Vec<Vec<VertexId>>Vertex lists of all the shortest paths, grouped by target in increasing target id order. Unreachable targets contribute no path.
edges: Vec<Vec<EdgeId>>Edge lists of the same paths, in the same order.
nrgeo: Vec<i64>Number of shortest paths from the source to each vertex (indexed by vertex id). Only accurate for the requested targets.