GraphPath

Struct GraphPath 

pub struct GraphPath {
    pub vertices: Vec<VertexId>,
    pub edges: Vec<EdgeId>,
}
A single path, described both by the vertices it visits and by the edges it traverses.

For a path of k edges, vertices has k + 1 entries (source and target included) and edges has k entries. An empty vertices list means that there is no path.

Fields

vertices: Vec<VertexId>

The vertex ids along the path, including both endpoints.

edges: Vec<EdgeId>

The edge ids along the path.

Implementations

Source

impl GraphPath

pub fn len(&self) -> usize

Number of edges of the path (its unweighted length).

pub fn is_empty(&self) -> bool

Whether the path has no edges (no path at all, or a path from a vertex to itself).

pub fn exists(&self) -> bool

Whether a path was found, i.e. vertices is non-empty.

pub fn weight(&self, weights: &[f64]) -> f64

Sum of the weights of the traversed edges (weights is indexed by edge id).

Panics

If some edge id of the path is out of the bounds of weights.