pub struct PathLengthHistogram {
pub counts: Vec<f64>,
pub unconnected: f64,
}Expand description
Histogram of shortest path lengths, see Graph::path_length_hist.
Fields
counts: Vec<f64>counts[i] is the number of vertex pairs at distance i + 1.
unconnected: f64The number of vertex pairs whose second vertex is unreachable from the first.