pub struct ShortestPaths {
pub vertices: Vec<Vec<VertexId>>,
pub edges: Vec<Vec<EdgeId>>,
pub parents: Vec<VertexId>,
pub inbound_edges: Vec<EdgeId>,
}Expand description
Single-source shortest (or widest) paths towards a set of targets, as
returned by Graph::get_shortest_paths and friends.
Fields
vertices: Vec<Vec<VertexId>>vertices[i] lists the vertices on the path to the i-th target
(empty if the target is unreachable).
edges: Vec<Vec<EdgeId>>edges[i] lists the edges on the path to the i-th target.
parents: Vec<VertexId>The shortest path tree, indexed by vertex id: the vertex from which each
vertex was reached. The source has -1, and vertices not reached
during the search have -2 (the search stops as soon as all the
targets are reached).
inbound_edges: Vec<EdgeId>The shortest path tree, indexed by vertex id: the edge through which
each vertex was reached; -1 for the source and unreached vertices.
Implementations